@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from openstack import connection
 from oslo_log import log as logging
 from oslo_versionedobjects import base as object_base
@@ -139,7 +137,8 @@ class ExtARQ(base.CyborgObject, object_base.VersionedObjectDictCompat,
             msg = ("Failed to change ARQ state from %s to %s, the current "
                    "state is %s" % (old, state, current))
             LOG.error(msg)
-            raise exception.ARQInvalidState(msg)
+            raise exception.ARQBadState(
+                state=current, uuid=self.arq.uuid, expected=list(state))
         return True
 
     def destroy(self, context):
@@ -194,7 +193,7 @@ class ExtARQ(base.CyborgObject, object_base.VersionedObjectDictCompat,
         except Exception as e:
             LOG.error("Failed to allocate attach handle for ARQ %s"
                       "from deployable %s. Reason: %s",
-                      self.arq.uuid, deployable.uuid, six.text_type(e))
+                      self.arq.uuid, deployable.uuid, str(e))
             # TODO(Shaohe) Rollback? We have _update_placement,
             # should cancel it.
             self.update_check_state(
@@ -278,7 +277,7 @@ class ExtARQ(base.CyborgObject, object_base.VersionedObjectDictCompat,
 
         for field in extarq.fields:
             if field != 'arq':
-                extarq[field] = db_extarq[field]
+                extarq[field] = db_extarq.get(field)
         extarq.arq = objects.ARQ()
         extarq.arq._from_db_object(extarq.arq, db_extarq)
         extarq.obj_reset_changes()
